@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -216,14 +216,13 @@ class WorkflowsAsyncClient:
         r"""Lists Workflows in a given project and location.
         The default order is not specified.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
-            def sample_list_workflows():
+            async def sample_list_workflows():
                 # Create a client
-                client = workflows_v1beta.WorkflowsClient()
+                client = workflows_v1beta.WorkflowsAsyncClient()
 
                 # Initialize request argument(s)
                 request = workflows_v1beta.ListWorkflowsRequest(
@@ -234,7 +233,7 @@ class WorkflowsAsyncClient:
                 page_result = client.list_workflows(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -299,12 +298,20 @@ class WorkflowsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListWorkflowsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -321,13 +328,13 @@ class WorkflowsAsyncClient:
     ) -> workflows.Workflow:
         r"""Gets details of a single Workflow.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
-            def sample_get_workflow():
+            async def sample_get_workflow():
                 # Create a client
-                client = workflows_v1beta.WorkflowsClient()
+                client = workflows_v1beta.WorkflowsAsyncClient()
 
                 # Initialize request argument(s)
                 request = workflows_v1beta.GetWorkflowRequest(
@@ -335,7 +342,7 @@ class WorkflowsAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_workflow(request=request)
+                response = await client.get_workflow(request=request)
 
                 # Handle the response
                 print(response)
@@ -397,7 +404,12 @@ class WorkflowsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -418,14 +430,13 @@ class WorkflowsAsyncClient:
         running operation will return
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
-            def sample_create_workflow():
+            async def sample_create_workflow():
                 # Create a client
-                client = workflows_v1beta.WorkflowsClient()
+                client = workflows_v1beta.WorkflowsAsyncClient()
 
                 # Initialize request argument(s)
                 workflow = workflows_v1beta.Workflow()
@@ -442,7 +453,7 @@ class WorkflowsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -532,7 +543,12 @@ class WorkflowsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -558,14 +574,13 @@ class WorkflowsAsyncClient:
         This method also cancels and deletes all running
         executions of the workflow.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
-            def sample_delete_workflow():
+            async def sample_delete_workflow():
                 # Create a client
-                client = workflows_v1beta.WorkflowsClient()
+                client = workflows_v1beta.WorkflowsAsyncClient()
 
                 # Initialize request argument(s)
                 request = workflows_v1beta.DeleteWorkflowRequest(
@@ -577,7 +592,7 @@ class WorkflowsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -616,9 +631,6 @@ class WorkflowsAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -652,7 +664,12 @@ class WorkflowsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -682,14 +699,13 @@ class WorkflowsAsyncClient:
         update operation. In that case, such revision will be
         used in new workflow executions.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import workflows_v1beta
 
-            def sample_update_workflow():
+            async def sample_update_workflow():
                 # Create a client
-                client = workflows_v1beta.WorkflowsClient()
+                client = workflows_v1beta.WorkflowsAsyncClient()
 
                 # Initialize request argument(s)
                 workflow = workflows_v1beta.Workflow()
@@ -704,7 +720,7 @@ class WorkflowsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -778,7 +794,12 @@ class WorkflowsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -800,7 +821,9 @@ class WorkflowsAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-workflows",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-workflows",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
